componenttools.iterate_namesakes_forward_from_component
=======================================================

.. autofunction:: abjad.tools.componenttools.iterate_namesakes_forward_from_component.iterate_namesakes_forward_from_component
